

export const index = 5;
let component_cache;
export const component = async () => component_cache ??= (await import('../entries/pages/(app)/notes/_layout.svelte.js')).default;
export const imports = ["_app/immutable/nodes/5.MvHJ7J5U.js","_app/immutable/chunks/BsAB9Z30.js","_app/immutable/chunks/IHki7fMi.js","_app/immutable/chunks/BrBP5fsK.js","_app/immutable/chunks/BY-rXZ0_.js"];
export const stylesheets = [];
export const fonts = [];
